XvcCommand

Enum XvcCommand 

pub enum XvcCommand {
    GetInfo,
    SetTck,
    Shift,
}
Possible commands that are known to the XVC protocol.

Variants



GetInfo



SetTck



Shift

Implementations

Source

impl XvcCommand

pub fn parse(buf: &mut &[u8]) -> Result<XvcCommand, ParseErr>

Parse a command from a buffer.

Example
use xvc_protocol::{XvcCommand};

let mut buf: &[u8] = b"getinfo:";
let command = XvcCommand::parse(&mut buf).expect("Parsing a large enough buffer should not fail");
assert_eq!(command, XvcCommand::GetInfo);
assert_eq!(buf.len(), 0);

If the buffer is not large enough, ParseErr::Incomplete is returned. This usually indicates to the caller to read more bytes into the buffer:

A buffer that is too large is permitted. After a successful parse the buffer is advanced past the consumed command bytes:

use xvc_protocol::XvcCommand;

let mut buf: &[u8] = b"settck:\x64";
let command = XvcCommand::parse(&mut buf).expect("Parsing a large enough buffer should not fail");
assert_eq!(command, XvcCommand::SetTck);
assert_eq!(buf.len(), 1);