XvcInfo

Struct XvcInfo 

pub struct XvcInfo { /* private fields */ }
Contains static information about the server capabilities that are transferred between client and server in the beginning.

Implementations

Source

impl XvcInfo

pub fn new(version: Version, max_vector_len: u32) -> XvcInfo

Creates a new info object from version and the maximum receivable vector length.

pub fn version(&self) -> Version

The version of the protocol

pub fn max_vector_len(&self) -> u32

the max width of the vector that can be shifted into the server

Source

impl XvcInfo

pub fn parse(buf: &mut &[u8]) -> Result<XvcInfo, ParseErr>

Source

impl XvcInfo

pub fn write_to(&self, writer: &mut impl Write) -> Result<()>

Write this XvcInfo to writer in the protocol’s server-info format.

The output has the form xvcServer_v<major>.<minor>:<max_vector_len>\n. This is the canonical representation sent by servers to announce capabilities to clients.

pub fn from_reader(reader: &mut impl Read) -> Result<XvcInfo, ReadError>

Read an XvcInfo from reader using an internal Decoder.

Example:

use std::io::Cursor;
let mut c = Cursor::new(b"xvcServer_v1.0:32\n");
let info = xvc_protocol::XvcInfo::from_reader(&mut c).unwrap();
assert_eq!(info.max_vector_len(), 32);