OwnedMessage

Type Alias OwnedMessage 

pub type OwnedMessage = Message<Box<[u8]>>;

Aliased Type

pub enum OwnedMessage {
    GetInfo,
    SetTck {
        period_ns: u32,
    },
    Shift {
        num_bits: u32,
        tms: Box<[u8]>,
        tdi: Box<[u8]>,
    },
}

Variants



GetInfo

Requests info from the server. This is used to determine protocol capabilities of the server.



SetTck

Configures the TCK period. When sending JTAG vectors the TCK rate may need to be varied to accommodate cable and board signal integrity conditions. This command is used by clients to adjust the TCK rate in order to slow down or speed up the shifting of JTAG vectors.

Fields

period_ns: u32


Shift

Used to shift JTAG vectors in-and out of a device.

Fields

num_bits: u32

represents the number of TCK clk toggles needed to shift the vectors out

tms: Box<[u8]>

a byte sized vector with all the TMS data. The vector is num_bits and rounds up to the nearest byte.

tdi: Box<[u8]>

a byte sized vector with all the TDI data. The vector is num_bits and rounds up to the nearest byte.