pub type OwnedMessage = Message<Box<[u8]>>;Aliased Type
pub enum OwnedMessage {
GetInfo,
SetTck {
period_ns: u32,
},
Shift {
num_bits: u32,
tms: Box<[u8]>,
tdi: Box<[u8]>,
},
}Variants
GetInfo
Requests info from the server. This is used to determine protocol capabilities of the server.
SetTck
Configures the TCK period. When sending JTAG vectors the TCK rate may need to be varied to accommodate cable and board signal integrity conditions. This command is used by clients to adjust the TCK rate in order to slow down or speed up the shifting of JTAG vectors.
Shift
Used to shift JTAG vectors in-and out of a device.